
# Slot: rules


the collection of rules that apply to all members of this class

URI: [linkml:rules](https://w3id.org/linkml/rules)


## Domain and Range

[ClassDefinition](ClassDefinition.md) &#8594;  <sub>0..\*</sub> [ClassRule](ClassRule.md)

## Parents


## Children

 *  [class_definition➞rules](class_definition_rules.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | sh:rule |

